OptionInstance

Trait OptionInstance 

pub trait OptionInstance<'s>: Instance<'s> {
    // Required methods
    fn value<'a>(&'a self) -> Option<Value<'a, 's>>
       where 's: 'a;
    fn boxed_clone(&self) -> Box<dyn OptionInstance<'s> + 's>;
    fn into_boxed_instance(self: Box<Self>) -> Box<dyn Instance<'s> + 's>;
}
A reflected Option

Required Methods

fn value<'a>(&'a self) -> Option<Value<'a, 's>>
where 's: 'a,

Returns a reference to a field in a reflected vec

fn boxed_clone(&self) -> Box<dyn OptionInstance<'s> + 's>

Returns a clone of the instance in a Box.

fn into_boxed_instance(self: Box<Self>) -> Box<dyn Instance<'s> + 's>